@@ -17,6 +17,10 @@
 from .base import (  # noqa
     Base,
 )
+from .const import (  # noqa
+    Priority,
+    Resolution,
+)
 from .user import (  # noqa
     NulabAccount,
     User,
